Metaphor-GM is modelling tool based on neural network technology.
It includes basic neural network technology as well as network factory 
for physical knowledge based neural models,
as well as  the Graph Machine technology for chemical formula based 
modelling.